@@ -139,7 +139,7 @@ on_wpm_spinbutton_value_changed(
     gpointer       user_data)
 {
   int val = gtk_spin_button_get_value_as_int( spin_button );
-  rc_data.unit_elem = (60 * rc_data.tone_freq) / (50 * CYCLES_PER_FRAG * val);
+  rc_data.unit_elem = (60 *rc_data.tone_freq) / (50 * val * CYCLES_PER_FRAG);
 }
 
 
