@@ -51,8 +51,7 @@ Adapt_Decoder( void )
             rc_data.unit_elem++;
 
       /* Display speed in wpm */
-      int ispeed = ( 60 * rc_data.tone_freq ) /
-        ( 50 * CYCLES_PER_FRAG * rc_data.unit_elem );
+      int ispeed = (60 * rc_data.tone_freq) / (50 * rc_data.unit_elem * CYCLES_PER_FRAG);
       gtk_spin_button_set_value( speed, (gdouble)ispeed );
 
     } /* if( isFlagSet(ADAPT_SPEED) ) */
