@@ -33,7 +33,7 @@
   "M","N","O","P","Q","R","S","T","U","V","W","X",  \
   "Y","Z","1","2","3","4","5","6","7","8","9","0",  \
   ".",",","?","\"","!","/","(",")","&",":",";","=", \
-  "+","-","_","\"","$","@","<OK>","<GO>","<BK>","<VA>", \
+  "+","-","_","\"","$","@","<OK>","<GO>","<BK>","<SK>", \
   "\u00c4","\u00d6","\u00dc","\u00df","<!!>"," ","*"
 
 /* Hex equivalents to Morse code chars above except (*).  */
