@@ -171,7 +171,7 @@ Demodulate_CW( short *signal_sample )
     double phi = 0.0;
 
     /* Length of sinf/cosf tables */
-    trig_len = PERSEUS_SAMPLE_RATE / PERSEUS_WEAVER_FREQ;
+    trig_len = PERSEUS_SAMPLE_RATE / rc_data.tone_freq;
 
     /* Allocate trigonometric tables */
     size_t req = (size_t)trig_len * sizeof(double);
