@@ -31,9 +31,6 @@
 /* Demodulator bandwidth 200 Hz */
 #define PERSEUS_DEMOD_BANDW     200.0
 
-/* Weaver phasing frequency. Will give a 500 Hz beat freq. */
-#define PERSEUS_WEAVER_FREQ     500
-
 /* Perseus receiver device index */
 #define PERSEUS_DEVICE_INDEX    0
 
