@@ -23,8 +23,12 @@ GtkWidget
   *waterfall,
   *scope_label;
 
+/* Receiver type combobox */
+GtkComboBoxText *receiver_combobox = NULL;
+
 /* Speed and squelch spin button */
 GtkSpinButton
+  *frequency,
   *speed,
   *squelch,
   *ratio;
@@ -58,11 +62,19 @@ gint
 /* Average bin values */
 int *bin_ave = NULL;
 
-/* dft in/out buffers */
-int
-  *dft_in_r  = NULL,
-  *dft_out_r = NULL,
-  *dft_out_i = NULL;
+/* IFFT data buffer*/
+int16_t
+  *ifft_data = NULL,
+  ifft_data_length = 0;
+
+sem_t pback_semaphore;
+
+/* Sound Playback Buffer has to be a ring
+ * buffer to allow for the differences in the
+ * SDR ADC and Sound card ADC sampling rates */
+short **playback_buf = NULL;
+int   sound_buf_num;
+int   demod_buf_num;
 
 /*------------------------------------------------------------------------*/
 
