@@ -533,8 +533,7 @@ Load_Config( gpointer data )
 
   /* Set spinbutton value */
   gtk_spin_button_set_value( speed, (gdouble)wpm );
-  rc_data.unit_elem =
-    (60 * rc_data.tone_freq) / (50 * CYCLES_PER_FRAG * wpm);
+  rc_data.unit_elem = (60 * rc_data.tone_freq) / (50 * wpm * CYCLES_PER_FRAG);
   rc_data.center_line = wfall_width / 2 + 1;
 
   /* Enable Transceiver CAT */
@@ -616,16 +615,14 @@ Waterfall_Configure_Event( int width, int height )
    * is an integer otherwise the waterfall is not accurate */
   if( idx )
   {
-    rc_data.ifft_stride = rc_data.dsp_rate / rc_data.tone_freq  / idx;
+    rc_data.ifft_stride = rc_data.dsp_rate / rc_data.tone_freq / idx;
     rc_data.tone_freq   = rc_data.dsp_rate / rc_data.ifft_stride / idx;
   }
 
   /* Calculate parameters that depend on above */
-  rc_data.max_unit = (60 * rc_data.tone_freq) /
-    (50 * CYCLES_PER_FRAG * rc_data.max_unit);
+  rc_data.max_unit    = (60 * rc_data.tone_freq) / (50 * rc_data.max_unit * CYCLES_PER_FRAG);
   rc_data.max_unit_x2 = rc_data.max_unit * 2;
-  rc_data.min_unit = (60 * rc_data.tone_freq) /
-    (50 * CYCLES_PER_FRAG * rc_data.min_unit);
+  rc_data.min_unit    = (60 * rc_data.tone_freq) / (50 * rc_data.min_unit * CYCLES_PER_FRAG);
 
 } /* Waterfall_Configure_Event() */
 
